@@ -75,24 +75,25 @@ def varmap(func, var, context=None):
 
 def has_sentry_metadata(value):
     try:
-        return callable(getattr(value, '__sentry__', None))
+        return callable(value.__getattribute__("__sentry__"))
     except:
         return False
 
 def transform(value, stack=[], context=None):
     # TODO: make this extendable
-    # TODO: include some sane defaults, like UUID
-    # TODO: dont coerce strings to unicode, leave them as strings
     if context is None:
         context = {}
+
     objid = id(value)
     if objid in context:
         return '<...>'
+
     context[objid] = 1
+    transform_rec = lambda o: transform(o, stack + [value], context)
+
     if any(value is s for s in stack):
         ret = 'cycle'
-    transform_rec = lambda o: transform(o, stack + [value], context)
-    if isinstance(value, (tuple, list, set, frozenset)):
+    elif isinstance(value, (tuple, list, set, frozenset)):
         ret = type(value)(transform_rec(o) for o in value)
     elif isinstance(value, uuid.UUID):
         ret = repr(value)
@@ -102,7 +103,7 @@ def transform(value, stack=[], context=None):
         ret = to_unicode(value)
     elif isinstance(value, str):
         try:
-            ret = str(value)
+            ret = str(value.decode('utf-8').encode('utf-8'))
         except:
             ret = to_unicode(value)
     elif not isinstance(value, (ClassType, TypeType)) and \
@@ -110,6 +111,7 @@ def transform(value, stack=[], context=None):
         ret = transform_rec(value.__sentry__())
     elif isinstance(value, Promise):
         # EPIC HACK
+        # handles lazy model instances (which are proxy values that dont easily give you the actual function)
         pre = value.__class__.__name__[1:]
         value = getattr(value, '%s__func' % pre)(*getattr(value, '%s__args' % pre), **getattr(value, '%s__kw' % pre))
         return transform(value)
@@ -305,4 +307,4 @@ class MockDjangoRequest(object):
         return '<Request\nGET:%s,\nPOST:%s,\nCOOKIES:%s,\nMETA:%s>' % \
             (get, post, cookies, meta)
 
-    def build_absolute_uri(self): return self.url
\ No newline at end of file
+    def build_absolute_uri(self): return self.url
